define(["require", "exports", "tslib", "react"], function (require, exports, tslib_1, React) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    // TODO: what is our augmentation story and uses cases?
    // TODO: if merged, figure out typing. could maybe provide a template accessor to prevent 'any' type arg
    // tslint:disable-next-line:no-any
    var _augmentations = {};
    // Helper function to tie them together.
    function createComponentWithProviders(options, providers) {
        var result = function (userProps) {
            var augmented = _augmentations[options.scope] || {};
            var StateComponent = augmented.state || options.state;
            var ViewComponent = augmented.view || options.view;
            var getStyles = augmented.styles || options.styles;
            var theme = providers.getTheme();
            ViewComponent.displayName = ViewComponent.displayName || options.scope + 'View';
            var content = function (processedProps) {
                var styles = undefined;
                if (typeof getStyles === 'function') {
                    // TODO: TS issues with spreading generic (even if that generic extends object)
                    //       https://github.com/Microsoft/TypeScript/issues/13557
                    //       workaround: Object.assign usage
                    // styles = (getStyles as IStyleFunction<TTheme, TProps & IThemeProps<TTheme>, TStyles>)({ theme, ...(processedProps as {}) });
                    var mergedProps = Object.assign({}, { theme: theme }, userProps);
                    styles = getStyles(mergedProps);
                }
                else {
                    styles = getStyles;
                }
                return React.createElement(ViewComponent, tslib_1.__assign({}, processedProps, { styles: providers.mergeStyleSets(styles) }));
            };
            return !!StateComponent ? React.createElement(StateComponent, tslib_1.__assign({}, userProps, { view: content })) : content(userProps);
        };
        result.displayName = options.scope;
        return result;
    }
    exports.createComponentWithProviders = createComponentWithProviders;
    // Helper function to augment existing components that have been created.
    function augmentComponent(options) {
        _augmentations[options.scope] = tslib_1.__assign({}, _augmentations[options.scope], options);
    }
    exports.augmentComponent = augmentComponent;
});
//# sourceMappingURL=createComponent.js.map