import * as React from 'react';
export interface IThemeProps<TTheme> {
    theme: TTheme;
}
export declare type IStyledProps<TProps, TTheme> = TProps & IThemeProps<TTheme>;
export declare type IStyleFunction<TStylesProps extends IThemeProps<TTheme>, TStyles, TTheme> = (props: TStylesProps) => TStyles;
export declare type IStateProps<TProps> = TProps & {
    view: (props: TProps) => JSX.Element;
};
export declare type IStylesProp<TProps extends IThemeProps<TTheme>, TStyles, TTheme> = IStyleFunction<TProps, TStyles, TTheme> | TStyles;
export declare type IViewProps<TProps, TStylesSet> = TProps & {
    styles: TStylesSet;
};
export interface IAugmentations<TUserProps extends IThemeProps<TTheme>, TStyles, TStyleSet, TTheme> {
    [scope: string]: IComponentOptions<TUserProps, TStyles, TStyleSet, TTheme>;
}
export interface IComponentOptions<TUserProps, TStyles, TStyleSet, TTheme> {
    scope: string;
    state?: React.ComponentType<IStateProps<TUserProps>>;
    styles: IStylesProp<TUserProps & IThemeProps<TTheme>, TStyles, TTheme>;
    view: React.ComponentType<IViewProps<TUserProps, TStyleSet>>;
}
export interface IStylingProviders<TStyles, TStyleSet, TTheme> {
    getTheme: () => TTheme;
    mergeStyleSets: (styles: TStyles) => TStyleSet;
}
export declare function createComponentWithProviders<TProps, TStyles, TStyleSet, TTheme>(options: IComponentOptions<TProps, TStyles, TStyleSet, TTheme>, providers: IStylingProviders<TStyles, TStyleSet, TTheme>): React.StatelessComponent<TProps>;
export declare function augmentComponent<TProps, TStyles, TStyleSet, TTheme>(options: IComponentOptions<TProps, TStyles, TStyleSet, TTheme>): void;
